@@ -321,7 +321,7 @@ class TestWalkMigrations(base.TestCase):
         test_ids = [data['tests'][x]['id'] for x in data['tests']]
         # Query the DB for the tests from the sample dataset above
         where = ' OR '.join(["tests.id='%s'" % x for x in test_ids])
-        result = tests.select(where).execute()
+        result = tests.select(sqlalchemy.sql.text(where)).execute()
         run_time_pairs = list(map(lambda x: (x['id'], x['run_time']), result))
         # Ensure the test with one failure is None
         self.assertIn(('fake_null_test_id_fails', None), run_time_pairs)
